@@ -227,7 +227,7 @@ class MultiLookUpMixin(UniqueFieldsMixin, NestedUpdateMixin):
 
             return instances
 
-        instance.update({
+        instances.update({
             self.__get_combined_key_from_instance(
                 related_instance,
                 self.__get_lookup_fields(field),
@@ -404,10 +404,7 @@ class MultiLookUpMixin(UniqueFieldsMixin, NestedUpdateMixin):
                 ).first()
 
         if self.instance:
-            return super(
-                MultiLookUpMixin,
-                self
-            ).update(self.instance, validated_data)
+            return self.update(self.instance, validated_data)
         else:
             return super(
                 MultiLookUpMixin,
